@@ -142,7 +142,7 @@ class DatosSMEC(TablasVC):
 
         return (entero if decimal < 0.5 else entero +1) * (-1 if numero < 0 else 1) 
     
-    def consultar_datos_vc(self,fecha_i=None,fecha_f=None,parques=[],mensajes=False):
+    def cargar_datos_vc(self,fecha_i=None,fecha_f=None,parques=[],mensajes=False):
         if fecha_i is None:
             fecha_i = self.fecha_i
         
@@ -276,4 +276,3 @@ class DatosSMEC(TablasVC):
                             .replace('fecha','t_stamp')) 
                     if filtro else df_)
             )
-
