@@ -74,8 +74,6 @@ def encontrar_archivos_faltantes(archivos_necesarios,archivos_disponibles):
     
     return [archivo for archivo in archivos_necesarios if archivo not in archivos_disponibles]
 
-def _concat_paths(path1,path2):
-    return __Path(str(path1)+str(path2))
 
 def check_dir(dir):
     '''Recibe una ruta, bien como objeto pathlib.Path o string
@@ -88,7 +86,7 @@ def check_dir(dir):
         raise TypeError('Se esperaba un objeto pathlib.Path o String como variable de entrada')
     
     if not dir.is_absolute():
-        dir = _concat_paths(raiz,dir)
+        dir = __Path(raiz).joinpath(dir)
     
     if dir.exists():
         if dir.is_dir():
@@ -113,16 +111,12 @@ def check_dirs(dir_list):
     for dir in dir_list:
         check_dir(dir)
 
-
 def check_archivo(file):
         if file.exists():
             return __Path(file)
         else:
             raise Exception(f'El archivo {file} no existe')
             
-    
-    
-
 def filtra_archivos(iterable,extension):
     '''busca en un iterable todos los archivos que terminen con la extensión determinada.
     Devuelve una lista de python de archivos con ruta completa como resultado.'''
