@@ -64,7 +64,7 @@ def año_op(fecha_actual,fecha_cod,formatos=__formatos_default_fecha,prevenir_fu
     dif_años = act.year - cod.year
     
     #Python puede comparar tuples, (x,y) < (a,b) = (x<a) & (y<b)
-    ajuste_mes_dia = (act.month,act.day) < (cod.month,cod.day) 
+    ajuste_mes_dia = (act.month, act.day) < (cod.month, cod.day) 
 
     return dif_años - ajuste_mes_dia + 1
 
@@ -90,13 +90,23 @@ def restar_mes(fecha,prevenir_futuro=False):
     if fecha.month == 1:
         return fecha.replace(year=fecha.year -1, month=12)
     else:
-        return fecha.replace(day=1) - __dt.timedelta(days=1)
+        return (fecha
+            .__sub__(__dt.timedelta(days=1))
+            .replace(day=1)
+        )
 
 def hoy():
-    return __dt.datetime.today().replace(hour=0,minute=0,second=0,microsecond=0)
+    return (__dt.datetime
+        .today()
+        .replace(hour=0,minute=0,second=0,microsecond=0)
+    )
 
 def ayer():
-    return __dt.datetime.today().replace(hour=0,minute=0,second=0,microsecond=0) - __dt.timedelta(days=1)
+    return (__dt.datetime
+        .today()
+        .replace(hour=0, minute=0, second=0, microsecond=0)
+        .__sub__(__dt.timedelta(days=1))
+    )
 
 def mes_dia_1(fecha,formatos=__formatos_default_fecha,prevenir_futuro=True):
     fecha = validar_fecha(fecha,formatos=formatos,prevenir_futuro=prevenir_futuro)
